import { getDevOpsCore } from '@thatdevops/core/devopsCore'
import path from 'path'

export async function devopsGit() {
	const { publishable = false, deployable = false } = getDevOpsCore()

	return [
		{
			label: 'Git & Packages',
			children: [
				{
					label: 'Commit',
					script: path.join(__dirname, 'src/commit'),
					paramQuestions: [
						{
							type: 'string',
							key: 'commitMessage',
							question: 'Enter commit message',
						},
						...(deployable
							? [
									{
										type: 'boolean',
										key: 'deploy',
										question: 'Trigger Amplify deployment?',
										default: 'n',
									},
							  ]
							: []),
					],
				},
				{
					label: 'Commit + Push',
					script: path.join(__dirname, 'src/commitPush'),
					default: true,
					paramQuestions: [
						{
							type: 'string',
							key: 'commitMessage',
							question: 'Enter commit message',
						},
						...(deployable
							? [
									{
										type: 'boolean',
										key: 'deploy',
										question: 'Trigger Amplify deployment?',
										default: 'n',
									},
							  ]
							: []),
					],
				},
				...(publishable
					? [
							{
								label: 'Commit + Push + Publish',
								script: path.join(__dirname, 'src/commitPushPublish'),
								paramQuestions: [
									{
										type: 'string',
										key: 'commitMessage',
										question: 'Enter commit message',
									},
									{
										type: 'boolean',
										key: 'force',
										question: 'Force publish?',
										default: 'n',
									},
									...(deployable
										? [
												{
													type: 'boolean',
													key: 'deploy',
													question: 'Trigger Amplify deployment?',
													default: 'n',
												},
										  ]
										: []),
								],
							},
					  ]
					: []),
				{
					label: 'Resync Local Packages',
					script: path.join(__dirname, 'src/resyncLocalPackages'),
				},
				{
					label: 'Resync External Packages',
					script: path.join(__dirname, 'src/resyncExternalPackages'),
				},
			],
		},
	]
}
export default devopsGit
