import { getDevOpsCore } from '@thatdevops/core/devopsCore'
import getProjectPkgs from '@thatdevops/core/pkgman/getProjectPkgs'
import Pkg from '@thatdevops/core/pkgman/Pkg'
import spawnSilently from '@thatdevops/core/utils/spawnSilently'
import fs from 'fs'
import path from 'path'

export async function doFindChangedPackages(): Promise<Pkg[]> {
	const { rootPath } = getDevOpsCore()
	const pkgs = await getProjectPkgs()
	const rootJsonPath = path.join(rootPath, 'package.json')
	const rootJson = JSON.parse(fs.readFileSync(rootJsonPath).toString())

	const changed = []
	for (const pkg of pkgs) {
		const lastDate = rootJson?.devops?.publishdates?.[pkg.name] ?? '2020-01-01T00:00:00Z'
		const fls = await spawnSilently(
			'git',
			['log', '--name-only', '--pretty=oneline', `--since="${lastDate}"`, pkg.relativePath],
			rootPath
		)
		if (fls.length) changed.push(pkg)
	}
	return changed
}
export default doFindChangedPackages
