import { getDevOpsCore } from '@thatdevops/core/devopsCore'
import getPkg from '@thatdevops/core/pkgman/getPkg'
import Pkg from '@thatdevops/core/pkgman/Pkg'
import writePkg from '@thatdevops/core/pkgman/writePkg'
import spawnSilently from '@thatdevops/core/utils/spawnSilently'
import { DateTime } from 'luxon'

export async function doPublishPackage(
	pkg: Pkg,
	newVersion: string,
	setDate: boolean = false
): Promise<void> {
	const { rootPath } = getDevOpsCore()
	console.log(`- ${pkg.json.name} to ${newVersion}`)

	await spawnSilently('yarn', ['publish', '--new-version', newVersion], pkg.location)

	if (setDate) {
		const now = DateTime.now().plus({ minute: 1 }).toISO()

		const rootPkg = getPkg(rootPath)
		rootPkg.json.devops = rootPkg.json.devops || {}
		rootPkg.json.devops.publishdates = rootPkg.json.devops.publishdates || {}
		rootPkg.json.devops.publishdates[pkg.json.name] = now
		writePkg(rootPkg)
	}
}
