"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.doResyncExternalPackages = exports.doResyncLocalPackages = void 0;
const devopsCore_1 = require("@thatdevops/core/devopsCore");
const getPkg_1 = require("@thatdevops/core/pkgman/getPkg");
const getProjectPkgMap_1 = __importDefault(require("@thatdevops/core/pkgman/getProjectPkgMap"));
const getProjectPkgs_1 = __importDefault(require("@thatdevops/core/pkgman/getProjectPkgs"));
const versionMatch_1 = __importDefault(require("@thatdevops/core/pkgman/versionMatch"));
const writePkg_1 = __importDefault(require("@thatdevops/core/pkgman/writePkg"));
const echo_1 = __importDefault(require("@thatdevops/core/utils/echo"));
const spawnSilently_1 = __importDefault(require("@thatdevops/core/utils/spawnSilently"));
const Logger_1 = __importDefault(require("@thats/utils/log/Logger"));
const batchPromiseAll_1 = __importDefault(require("@thats/utils/misc/batchPromiseAll"));
const path_1 = __importDefault(require("path"));
function doResyncLocalPackages() {
    return __awaiter(this, void 0, void 0, function* () {
        const { rootPath } = (0, devopsCore_1.getDevOpsCore)();
        const allPkgs = yield (0, getProjectPkgMap_1.default)(rootPath);
        const devopsPkg = (0, getPkg_1.getPkg)(path_1.default.join(rootPath, 'devops'));
        let hasChanged = processPkg(devopsPkg, allPkgs);
        const projectPackages = yield (0, getProjectPkgs_1.default)(rootPath);
        projectPackages.forEach(pkg => {
            hasChanged = processPkg(pkg, allPkgs) || hasChanged;
        });
        if (hasChanged) {
            (0, echo_1.default)('Yarn installing');
            yield (0, spawnSilently_1.default)('yarn', ['install'], rootPath);
        }
    });
}
exports.doResyncLocalPackages = doResyncLocalPackages;
function doResyncExternalPackages() {
    return __awaiter(this, void 0, void 0, function* () {
        const { rootPath, modulePaths = [] } = (0, devopsCore_1.getDevOpsCore)();
        const allPkgs = {};
        yield (0, batchPromiseAll_1.default)(modulePaths.map(modulePath => () => __awaiter(this, void 0, void 0, function* () {
            Object.assign(allPkgs, yield (0, getProjectPkgMap_1.default)(modulePath));
        })));
        const devopsPkg = (0, getPkg_1.getPkg)(path_1.default.join(rootPath, 'devops'));
        let hasChanged = processPkg(devopsPkg, allPkgs);
        const projectPackages = yield (0, getProjectPkgs_1.default)(rootPath);
        projectPackages.forEach(pkg => {
            hasChanged = processPkg(pkg, allPkgs) || hasChanged;
        });
        if (hasChanged) {
            (0, echo_1.default)('Yarn installing');
            yield (0, spawnSilently_1.default)('yarn', ['install'], rootPath);
        }
    });
}
exports.doResyncExternalPackages = doResyncExternalPackages;
function processPkg(pkg, allPkgs) {
    var _a, _b;
    let hasChanged = false;
    hasChanged = processDeps(pkg.name, (_a = pkg.json.dependencies) !== null && _a !== void 0 ? _a : {}, allPkgs) || hasChanged;
    hasChanged = processDeps(pkg.name, (_b = pkg.json.devDependencies) !== null && _b !== void 0 ? _b : {}, allPkgs) || hasChanged;
    if (hasChanged)
        (0, writePkg_1.default)(pkg);
    return hasChanged;
}
function processDeps(name, deps, allPkgs) {
    let hasChanged = false;
    for (const dep in deps) {
        if (!!allPkgs[dep] && !(0, versionMatch_1.default)(deps[dep], allPkgs[dep].version)) {
            hasChanged = true;
            deps[dep] = allPkgs[dep].version;
            Logger_1.default.info(` - ${name} - ${dep} => ${allPkgs[dep].version}`);
        }
    }
    return hasChanged;
}
//# sourceMappingURL=doResyncPackages.js.map